@@ -52,9 +52,12 @@ class ModelParser:
 
         file_path = str(model_path)
         try:
-            model_schema, keras_model = model_to_keras_converter(file_path)
+            model_schema, keras_model_with_weights = model_to_keras_converter(file_path)
             model_generator = KerasJsonModelImport(self.custom_layers)
 
+            keras_model = keras_model_with_weights
+            if keras_model is None:
+                keras_model = tf.keras.models.model_from_json(json.dumps(model_schema))
             layer_name_to_inbound_nodes = {
                 layer.name: layer.inbound_nodes
                 for layer in keras_model.layers
@@ -62,7 +65,7 @@ class ModelParser:
 
             graph, connected_inputs = model_generator.generate_graph(
                 model_schema, layer_name_to_inbound_nodes)
-            return graph, connected_inputs, keras_model
+            return graph, connected_inputs, keras_model_with_weights
         except Exception as e:
             if model_type.value in [ImportModelTypeEnum.H5_TF2.value, ImportModelTypeEnum.PB_TF2.value]:
                 if model_type.value == ImportModelTypeEnum.H5_TF2.value:
@@ -109,7 +112,7 @@ class ModelParser:
     def convert_json_model(cls, file_path: str) -> Tuple[Dict[str, NodeResponse], None]:
         with open(file_path, 'r') as f:
             model_schema = json.load(f)
-        return model_schema, tf.keras.models.model_from_json(json.dumps(model_schema))
+        return model_schema, None
 
     def convert_pb_model(self, file_path: str) -> Tuple[Dict[str, NodeResponse], Model]:
         k_model = self._get_k_model_from_pb_path(file_path)
